@@ -33,9 +33,10 @@ public:
 
   void sizeChanged(ScanDir* d)
   {
-    printf("Change in %s (Dirs %d, Files %d, Size %u)\n",
+    printf("Change in %s: Dirs %d, Files %d",
 	   d->name().latin1(), 
-	   d->dirCount(), d->fileCount(), d->size());
+	   d->dirCount(), d->fileCount());
+    printf("Size %llu\n", (unsigned long long int)d->size());
   }
 
   void scanFinished(ScanDir* d)
