@@ -28,6 +28,7 @@
 
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <kpassivepopup.h>
 #include <klocale.h>
 #include <kio/netaccess.h>
 #include <khtml_part.h>
@@ -38,7 +39,7 @@
 #include <qiodevice.h>
 #include <klistview.h>
 #include <kio/job.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kurllabel.h>
 #include <kprogress.h>
 #include <kstringhandler.h>
@@ -152,8 +153,7 @@ void ArchiveDialog::setSavingState()
    file.remove();
    m_tarBall->close();
 
-   KMessageBox::information(0L, i18n( "Archiving webpage completed." ),
-       QString::null, QString::null, false);
+   KPassivePopup::message( m_url.prettyURL() , i18n( "Archiving webpage completed." ), this );
 
    enableButtonOK(true);
    setEscapeButton(Ok);
